@@ -42,18 +42,42 @@ test_that("Returns the correct number of predictors.", {
 })
 
 test_that("Returns the correct range for x.", {
-  expect_true(max(simulate_negative_binomial(weights = .5, xrange = 0)[, 2]) <= 1)
-  expect_true(min(simulate_negative_binomial(weights = .5, xrange = 0)[, 2]) >= 1)
-  expect_true(max(simulate_negative_binomial(weights = .5, xrange = 2)[, 2]) <= 3)
-  expect_true(min(simulate_negative_binomial(weights = .5, xrange = 2)[, 2]) >= 1)
-  expect_true(max(simulate_negative_binomial(weights = .5, xrange = 3)[, 2]) <= 4)
-  expect_true(min(simulate_negative_binomial(weights = .5, xrange = 3)[, 2]) >= 1)
-  expect_true(max(simulate_negative_binomial(weights = c(.5, 1), xrange = 0)[, 3]) <= 1)
-  expect_true(min(simulate_negative_binomial(weights = c(.5, 1), xrange = 0)[, 3]) >= 1)
-  expect_true(max(simulate_negative_binomial(weights = c(.5, 1), xrange = 2)[, 3]) <= 3)
-  expect_true(min(simulate_negative_binomial(weights = c(.5, 1), xrange = 2)[, 3]) >= 1)
-  expect_true(max(simulate_negative_binomial(weights = c(.5, 1), xrange = 3)[, 3]) <= 4)
-  expect_true(min(simulate_negative_binomial(weights = c(.5, 1), xrange = 3)[, 3]) >= 1)
+  expect_true(
+    max(simulate_negative_binomial(weights = .5, x_range = 0)[, 2]) <= 1
+  )
+  expect_true(
+    min(simulate_negative_binomial(weights = .5, x_range = 0)[, 2]) >= 1
+  )
+  expect_true(
+    max(simulate_negative_binomial(weights = .5, x_range = 2)[, 2]) <= 3
+  )
+  expect_true(
+    min(simulate_negative_binomial(weights = .5, x_range = 2)[, 2]) >= 1
+  )
+  expect_true(
+    max(simulate_negative_binomial(weights = .5, x_range = 3)[, 2]) <= 4
+  )
+  expect_true(
+    min(simulate_negative_binomial(weights = .5, x_range = 3)[, 2]) >= 1
+  )
+  expect_true(
+    max(simulate_negative_binomial(weights = c(.5, 1), x_range = 0)[, 3]) <= 1
+  )
+  expect_true(
+    min(simulate_negative_binomial(weights = c(.5, 1), x_range = 0)[, 3]) >= 1
+  )
+  expect_true(
+    max(simulate_negative_binomial(weights = c(.5, 1), x_range = 2)[, 3]) <= 3
+  )
+  expect_true(
+    min(simulate_negative_binomial(weights = c(.5, 1), x_range = 2)[, 3]) >= 1
+  )
+  expect_true(
+    max(simulate_negative_binomial(weights = c(.5, 1), x_range = 3)[, 3]) <= 4
+  )
+  expect_true(
+    min(simulate_negative_binomial(weights = c(.5, 1), x_range = 3)[, 3]) >= 1
+  )
 })
 
 test_that("Returns the correct number of unrelated variables.", {
@@ -62,20 +86,36 @@ test_that("Returns the correct number of unrelated variables.", {
   expect_equal(ncol(simulate_negative_binomial(weights = 1, unrelated = 2)), 4)
   expect_equal(ncol(simulate_negative_binomial(weights = 1, unrelated = 3)), 5)
 
-  expect_equal(ncol(simulate_negative_binomial(weights = 1:2, unrelated = 0)), 3)
-  expect_equal(ncol(simulate_negative_binomial(weights = 1:2, unrelated = 1)), 4)
-  expect_equal(ncol(simulate_negative_binomial(weights = 1:2, unrelated = 2)), 5)
-  expect_equal(ncol(simulate_negative_binomial(weights = 1:2, unrelated = 3)), 6)
+  expect_equal(
+    ncol(simulate_negative_binomial(weights = 1:2, unrelated = 0)),
+    3
+  )
+  expect_equal(
+    ncol(simulate_negative_binomial(weights = 1:2, unrelated = 1)),
+    4
+  )
+  expect_equal(
+    ncol(simulate_negative_binomial(weights = 1:2, unrelated = 2)),
+    5
+  )
+  expect_equal(
+    ncol(simulate_negative_binomial(weights = 1:2, unrelated = 3)),
+    6
+  )
 })
 
 test_that("All links execute", {
-  expect_true(all(class(simulate_negative_binomial(link = "log")) == c("tbl_df", "tbl", "data.frame")))
-  expect_true(all(class(simulate_negative_binomial(link = "identity")) == c("tbl_df", "tbl", "data.frame")))
-  expect_true(all(class(simulate_negative_binomial(link = "sqrt")) == c("tbl_df", "tbl", "data.frame")))
+  expect_true(all(class(simulate_negative_binomial(link = "log")) ==
+    c("tbl_df", "tbl", "data.frame")))
+  expect_true(all(class(simulate_negative_binomial(link = "identity")) ==
+    c("tbl_df", "tbl", "data.frame")))
+  expect_true(all(class(simulate_negative_binomial(link = "sqrt")) ==
+    c("tbl_df", "tbl", "data.frame")))
 })
 
 test_that("Ancillary parameter works as expected", {
-  expect_true(simulate_negative_binomial()$Y %>% sd() > simulate_negative_binomial(ancillary = 5)$Y %>% sd())
+  expect_true(simulate_negative_binomial()$Y %>% sd() >
+    simulate_negative_binomial(ancillary = 5)$Y %>% sd())
 })
 
 ###############################################
@@ -86,10 +126,10 @@ test_that("Confirm input checing works.", {
   expect_error(simulate_negative_binomial(N = c(100, 200)), NULL)
   expect_error(simulate_negative_binomial(link = "1/mu^2"), NULL)
   expect_error(simulate_negative_binomial(weights = c()), NULL)
-  expect_error(simulate_negative_binomial(xrange = "asdf"), NULL)
-  expect_error(simulate_negative_binomial(xrange = c()), NULL)
-  expect_error(simulate_negative_binomial(xrange = c(1, 2)), NULL)
-  expect_error(simulate_negative_binomial(xrange = -1), NULL)
+  expect_error(simulate_negative_binomial(x_range = "asdf"), NULL)
+  expect_error(simulate_negative_binomial(x_range = c()), NULL)
+  expect_error(simulate_negative_binomial(x_range = c(1, 2)), NULL)
+  expect_error(simulate_negative_binomial(x_range = -1), NULL)
   expect_error(simulate_negative_binomial(unrelated = -1), NULL)
   expect_error(simulate_negative_binomial(unrelated = c(10, 20)), NULL)
   expect_error(simulate_negative_binomial(ancillary = -1), NULL)
